==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Wi-Fi ativado</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Wi-Fi desativado</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock ativado</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock desativado</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Teclado numérico ativado</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Teclado numérico desativado</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad ativado</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad desativado</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Alternar touchpad</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Alternar Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Modo avião ativado</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Modo avião desativado</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Mudo ativado</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Mudo desativado</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Equilibrado</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Economia de energia</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Alto desempenho</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Efeitos visuais ativados</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Efeitos visuais desativados</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Falha ao ativar os efeitos visuais</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.1.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Wi-Fi ativado</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Wi-Fi desativado</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock ativado</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock desativado</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Teclado numérico ativado</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Teclado numérico desativado</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad ativado</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad desativado</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Alternar touchpad</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Alternar Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Modo avião ativado</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Modo avião desativado</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Mudo ativado</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Mudo desativado</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Equilibrado</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Economia de energia</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Alto desempenho</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Efeitos visuais ativados</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Efeitos visuais desativados</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Falha ao ativar os efeitos visuais</translation>
    </message>
</context>
</TS>
